@@ -2,7 +2,9 @@ import logging
 from .resnet_enc import ResNet_D, BasicBlock
 from .res_shortcut_enc import ResShortCut_D
 
-__all__ = ['res_shortcut_encoder_29']
+RES_SHORTCUT_ENCODER_29 = 'res_shortcut_encoder_29'
+
+__all__ = [RES_SHORTCUT_ENCODER_29]
 
 
 def _res_shortcut_D(block, layers, **kwargs):
